@@ -4,9 +4,7 @@ from pytest_httpserver import HTTPServer
 
 
 def test_querystring_str(httpserver: HTTPServer):
-    httpserver.expect_request("/foobar", query_string="foo=bar", method="GET").respond_with_data(
-        "example_response"
-    )
+    httpserver.expect_request("/foobar", query_string="foo=bar", method="GET").respond_with_data("example_response")
     response = requests.get(httpserver.url_for("/foobar?foo=bar"))
     httpserver.check_assertions()
     assert response.text == "example_response"
@@ -14,9 +12,7 @@ def test_querystring_str(httpserver: HTTPServer):
 
 
 def test_querystring_bytes(httpserver: HTTPServer):
-    httpserver.expect_request("/foobar", query_string=b"foo=bar", method="GET").respond_with_data(
-        "example_response"
-    )
+    httpserver.expect_request("/foobar", query_string=b"foo=bar", method="GET").respond_with_data("example_response")
     response = requests.get(httpserver.url_for("/foobar?foo=bar"))
     httpserver.check_assertions()
     assert response.text == "example_response"
